/*	$OpenBSD: octboot.h,v 1.2 2020/05/26 13:21:58 visa Exp $	*/

/*
 * Copyright (c) 2019-2020 Visa Hankala
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#ifndef _OCTEON_OCTBOOT_H_
#define _OCTEON_OCTBOOT_H_

#include <sys/ioccom.h>

#define OCTBOOT_MAX_ARGS	8	/* maximum number of boot arguments */

struct octboot_kexec_args {
	char		*kimg;		/* kernel image buffer */
	size_t		 klen;		/* size of kernel image */
	char		*argv[OCTBOOT_MAX_ARGS];
					/* kernel boot arguments */
};

#define OBIOC_KEXEC		_IOW('O', 1, struct octboot_kexec_args)
#define OBIOC_GETROOTDEV	_IOR('O', 2, char[PATH_MAX])

#endif /* !_OCTEON_OCTBOOT_H_ */
